@@ -1,5 +1,3 @@
-/* $Id: rewrite_tag.c,v 1.7 2015-06-20 16:33:40 bfriesen Exp $ */
-
 /*
  * Copyright (c) 2007, Frank Warmerdam <warmerdam@pobox.com>
  *
@@ -32,6 +30,7 @@
 #include "tif_config.h"
 
 #include <stdio.h>
+#include <stdlib.h>
 
 #ifdef HAVE_UNISTD_H 
 # include <unistd.h> 
@@ -40,7 +39,6 @@
 #include "tiffio.h"
 #include "tiffiop.h"
 
-const uint32	width = 10;
 const uint32	length = 40;
 const uint32	rows_per_strip = 1;
 
@@ -51,6 +49,7 @@ int test_packbits()
     int             i;
     unsigned char   buf[10] = {0,0,0,0,0,0,0,0,0,0};
 
+    uint32 width = 10;
     int  length = 20;
     const char *filename = "test_packbits.tif";
 
@@ -138,17 +137,20 @@ int test_packbits()
 /************************************************************************/
 /*                            rewrite_test()                            */
 /************************************************************************/
-int rewrite_test( const char *filename, int length, int bigtiff, 
+int rewrite_test( const char *filename, uint32 width, int length, int bigtiff, 
                   uint64 base_value )
 
 {
     TIFF		*tif;
     int			i;
-    unsigned char	buf[10] = {5,6,7,8,9,10,11,12,13,14};
+    unsigned char	*buf;
     uint64		*rowoffset, *rowbytes;
     uint64		*upd_rowoffset;
     uint64		*upd_bytecount;
 
+    buf = calloc(1, width);
+    assert(buf);
+
     /* Test whether we can write tags. */
     if( bigtiff )
         tif = TIFFOpen(filename, "w8");
@@ -157,6 +159,7 @@ int rewrite_test( const char *filename, int length, int bigtiff,
 
     if (!tif) {
         fprintf (stderr, "Can't create test TIFF file %s.\n", filename);
+        free(buf);
         return 1;
     }
 
@@ -204,6 +207,7 @@ int rewrite_test( const char *filename, int length, int bigtiff,
     tif = TIFFOpen(filename, "r+");
     if (!tif) {
         fprintf (stderr, "Can't open test TIFF file %s.\n", filename);
+        free(buf);
         return 1;
     }
         
@@ -221,7 +225,7 @@ int rewrite_test( const char *filename, int length, int bigtiff,
 
     upd_rowoffset = (uint64 *) _TIFFmalloc(sizeof(uint64) * length);
     for( i = 0; i < length; i++ )
-        upd_rowoffset[i] = base_value + i*10;
+        upd_rowoffset[i] = base_value + i*width;
 
     if( !_TIFFRewriteField( tif, TIFFTAG_STRIPOFFSETS, TIFF_LONG8, 
                             length, upd_rowoffset ) )
@@ -234,7 +238,7 @@ int rewrite_test( const char *filename, int length, int bigtiff,
 
     upd_bytecount = (uint64 *) _TIFFmalloc(sizeof(uint64) * length);
     for( i = 0; i < length; i++ )
-        upd_bytecount[i] = 100 + i*10;
+        upd_bytecount[i] = 100 + i*width;
 
     if( !_TIFFRewriteField( tif, TIFFTAG_STRIPBYTECOUNTS, TIFF_LONG8, 
                             length, upd_bytecount ) )
@@ -252,6 +256,7 @@ int rewrite_test( const char *filename, int length, int bigtiff,
     tif = TIFFOpen(filename, "r");
     if (!tif) {
         fprintf (stderr, "Can't open test TIFF file %s.\n", filename);
+        free(buf);
         return 1;
     }
         
@@ -263,7 +268,7 @@ int rewrite_test( const char *filename, int length, int bigtiff,
         
     for( i = 0; i < length; i++ )
     {
-        uint64 expect = base_value + i*10;
+        uint64 expect = base_value + i*width;
 
         if( rowoffset[i] != expect )
         {
@@ -286,7 +291,7 @@ int rewrite_test( const char *filename, int length, int bigtiff,
         
     for( i = 0; i < length; i++ )
     {
-        uint64 expect = 100 + i*10;
+        uint64 expect = 100 + i*width;
 
         if( rowbytes[i] != expect )
         {
@@ -302,6 +307,7 @@ int rewrite_test( const char *filename, int length, int bigtiff,
     }
 
     TIFFClose( tif );
+    free(buf);
 
     /* All tests passed; delete file and exit with success status. */
     unlink(filename);
@@ -310,6 +316,7 @@ int rewrite_test( const char *filename, int length, int bigtiff,
   failure:
     /* Something goes wrong; close file and return unsuccessful status. */
     TIFFClose(tif);
+    free(buf);
     /*  unlink(filename); */
 
     return 1;
@@ -320,26 +327,27 @@ int rewrite_test( const char *filename, int length, int bigtiff,
 /*                                main()                                */
 /************************************************************************/
 int
-main(int argc, char **argv)
+main(void)
 {
     int failure = 0;
 
-    (void) argc;
-    (void) argv;
-
     failure |= test_packbits();
 
     /* test fairly normal use */
-    failure |= rewrite_test( "rewrite1.tif", 10, 0, 100 );
-    failure |= rewrite_test( "rewrite2.tif", 10, 1, 100 );
+    failure |= rewrite_test( "rewrite1.tif", 10, 10, 0, 100 );
+    failure |= rewrite_test( "rewrite2.tif", 10, 10, 1, 100 );
 
     /* test case of fitting all in directory entry */
-    failure |= rewrite_test( "rewrite3.tif", 1, 0, 100 );
-    failure |= rewrite_test( "rewrite4.tif", 1, 1, 100 );
+    failure |= rewrite_test( "rewrite3.tif", 10, 1, 0, 100 );
+    failure |= rewrite_test( "rewrite4.tif", 10, 1, 1, 100 );
 
     /* test with very large values that don't fit in 4bytes (bigtiff only) */
-    failure |= rewrite_test( "rewrite5.tif", 1000, 1, 0x6000000000ULL );
-    failure |= rewrite_test( "rewrite6.tif", 1, 1, 0x6000000000ULL );
+    failure |= rewrite_test( "rewrite5.tif", 10, 1000, 1, 0x6000000000ULL );
+    failure |= rewrite_test( "rewrite6.tif", 10, 1, 1, 0x6000000000ULL );
+
+    /* StripByteCounts on LONG */
+    failure |= rewrite_test( "rewrite7.tif", 65536, 1, 0, 100 );
+    failure |= rewrite_test( "rewrite8.tif", 65536, 2, 0, 100 );
 
     return failure;
 }
